.. _api:

.. _autodoc: http://sphinx-doc.org/ext/autodoc.html

==================
API of ``beradio``
==================

.. automodule:: beradio.protocol

    .. autoclass:: BERadioProtocol2
        :members:
        :private-members:
        :undoc-members:

----

.. automodule:: beradio.message
    :members:
    :private-members:
    :undoc-members:

    .. autoclass:: BERadioMessage

        .. automethod:: __init__
